@@ -29,14 +29,14 @@ class DashApp():
         if self.positions_stats['Duration'].mean() > 3000:
             self.positions_stats['Duration'] = self.positions_stats['Duration'] / 60 / 24
             self.duration_tag = 'Duration (d)'        
-            self.duration_size = self.positions_stats['Duration'].max()/10
+            self.duration_size = int(self.positions_stats['Duration'].max()/10)
         elif self.positions_stats['Duration'].mean() > 180:
             self.positions_stats['Duration'] = self.positions_stats['Duration'] / 60
-            self.duration_size = self.positions_stats['Duration'].max()/10
+            self.duration_size = int(self.positions_stats['Duration'].max()/10)
             self.duration_tag = 'Duration (h)'
         else:
             self.duration_tag = 'Duration (min)'
-            self.duration_size = self.positions_stats['Duration'].max()/10
+            self.duration_size = int(self.positions_stats['Duration'].max()/10)
 
 
         self.positions = pd.read_csv(system_path+'/backtest_results/userpositions.csv',sep=',')# ,format="%d/%m/%y %H:%M:00"
